@@ -36,7 +36,7 @@ class ApiWrapper:
         ) as websocket:
             await websocket.send(constraints_obj.json())
 
-            while await (msg := websocket.recv()):
+            while msg := await websocket.recv():
                 logging.info(msg)
 
             res = await websocket.recv()
